@@ -4,4 +4,4 @@ def test_get_version(client):
     response = client.get_version()
     assert 'pkgVersion' in response
     assert 'commitSha' in response
-    assert 'buildDate' in response
+    assert 'commitDate' in response
